==> carbon-components-react-0.2.8.tgz: package/es/components/Tour/Tour.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import { Walktour } from 'walktour';
import TourTooltip from '../TourTooltip';
import PropTypes from 'prop-types';

var Tour =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Tour, _React$Component);

  function Tour(props) {
    var _this;

    _classCallCheck(this, Tour);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tour).call(this, props));
    _this.state = {
      checked: false
    };
    return _this;
  }

  _createClass(Tour, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      return React.createElement(Walktour, _extends({}, this.props, {
        customTooltipRenderer: function customTooltipRenderer(logic) {
          var _logic$stepContent = logic.stepContent,
              title = _logic$stepContent.title,
              description = _logic$stepContent.description,
              disableClose = _logic$stepContent.disableClose,
              disableNext = _logic$stepContent.disableNext,
              disablePrev = _logic$stepContent.disablePrev,
              nextLabel = _logic$stepContent.nextLabel,
              prevLabel = _logic$stepContent.prevLabel,
              closeLabel = _logic$stepContent.closeLabel;
          var onClose = _this2.props.onClose ? function () {
            _this2.props.onClose(_this2.state.checked);

            logic.close();
          } : logic.close;
          return React.createElement(TourTooltip, _extends({
            onChangeChecked: function onChangeChecked(val) {
              return _this2.setState({
                checked: val
              });
            },
            checked: _this2.state.checked
          }, _this2.props, {
            onNext: logic.next,
            onPrev: logic.prev,
            onClose: onClose,
            description: description,
            title: title,
            disableClose: disableClose,
            disableNext: disableNext,
            disablePrev: disablePrev,
            nextLabel: nextLabel,
            prevLabel: prevLabel,
            closeLabel: closeLabel
          }));
        }
      }));
    }
  }]);

  return Tour;
}(React.Component);

export { Tour as default };
Tour.propTypes = {
  /**
   * An array of steps that the tour should follow
   */
  steps: PropTypes.arrayOf(PropTypes.shape({
    selector: PropTypes.string,
    description: PropTypes.string.isRequired,
    title: PropTypes.string,
    nextLabel: PropTypes.string,
    prevLabel: PropTypes.string,
    closeLabel: PropTypes.string,
    disableNext: PropTypes.bool,
    disablePrev: PropTypes.bool,
    disableClose: PropTypes.bool,
    customNextFunc: PropTypes.func,
    customPrevFunc: PropTypes.func,
    customCloseFunc: PropTypes.func
  })).isRequired,

  /** Optionally specify a custom close function for the entire tour. The checkbox state is passed as an argument to the callback
   *
   */
  onClose: PropTypes.func,

  /**
   * Optionally specify whether the tour should watch for changes to the target's size or position.
   */
  movingTarget: PropTypes.bool,

  /**
   * Optional identifier to differentiate between multiple tours on the same page.
   */
  identifier: PropTypes.string,

  /**
   * Optionally specify whether the mask should be disabled
   */
  disableMask: PropTypes.bool,

  /**
   * Optionally disable automatic scrolling
   */
  disableAutoScroll: PropTypes.bool,

  /**
   * Optionally provide a callback that handles receiving an update function. Can be used to listen
   * for events and recalculate the tour's position when those events fire. The callback will be
   * passed `update` as an argument.
   */
  setUpdateListener: PropTypes.func,

  /**
   * Optionally provide a callback intended to remove the listener set by `setUpdateListener`.
   * The callback will be passed `update` as an argument. Should only and always be used with `setUpdateListener`.
   */
  removeUpdateListener: PropTypes.func,

  /**
   * Optionally specify whether the tour is active or not. If specified, the tour will act as
   * a controlled component, and will defer to this prop when closing.
   */
  isOpen: PropTypes.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: PropTypes.bool,

  /**
   * Optionally specify whether the "close" button should be hidden
   */
  hideClose: PropTypes.bool
};

==> carbon-components-react-0.3.0.tgz: package/es/components/Tour/Tour.js <==
function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import { Walktour } from 'walktour';
import TourTooltip from '../TourTooltip';
import PropTypes from 'prop-types';

var Tour =
/*#__PURE__*/
function (_React$Component) {
  _inherits(Tour, _React$Component);

  function Tour(props) {
    var _this;

    _classCallCheck(this, Tour);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Tour).call(this, props));
    _this.state = {
      flipped: false
    };
    return _this;
  }

  _createClass(Tour, [{
    key: "render",
    value: function render() {
      var _this2 = this;

      var _this$props = this.props,
          flippedTitle = _this$props.flippedTitle,
          flippedDescription = _this$props.flippedDescription,
          enableFlip = _this$props.enableFlip;
      return React.createElement(Walktour, _extends({}, this.props, {
        customCloseFunc: function customCloseFunc(logic) {
          if (_this2.props.onClose) {
            _this2.props.onClose(logic.stepIndex);
          }

          logic.close();
        },
        customTooltipRenderer: function customTooltipRenderer(logic) {
          var _logic$stepContent = logic.stepContent,
              title = _logic$stepContent.title,
              description = _logic$stepContent.description,
              disableNext = _logic$stepContent.disableNext,
              disablePrev = _logic$stepContent.disablePrev,
              nextLabel = _logic$stepContent.nextLabel,
              prevLabel = _logic$stepContent.prevLabel;
          return React.createElement(TourTooltip, _extends({}, enableFlip && {
            enableFlip: true,
            flipped: _this2.state.flipped,
            onFlip: function onFlip() {
              return _this2.setState({
                flipped: !_this2.state.flipped
              });
            }
          }, {
            flippedTitle: flippedTitle,
            flippedDescription: flippedDescription
          }, _this2.props, {
            onNext: logic.next,
            onPrev: logic.prev,
            onClose: logic.close,
            description: description,
            title: title,
            disableNext: disableNext,
            disablePrev: disablePrev,
            nextLabel: nextLabel,
            prevLabel: prevLabel
          }));
        }
      }));
    }
  }]);

  return Tour;
}(React.Component);

export { Tour as default };
Tour.propTypes = {
  /**
   * An array of steps that the tour should follow
   */
  steps: PropTypes.arrayOf(PropTypes.shape({
    selector: PropTypes.string,
    description: PropTypes.string.isRequired,
    title: PropTypes.string,
    nextLabel: PropTypes.string,
    prevLabel: PropTypes.string,
    disableNext: PropTypes.bool,
    disablePrev: PropTypes.bool,
    customNextFunc: PropTypes.func,
    customPrevFunc: PropTypes.func,
    disableAutoScroll: PropTypes.bool,
    disableSmoothScroll: PropTypes.bool,
    movingTarget: PropTypes.bool,
    maskPadding: PropTypes.number,
    tooltipSeparation: PropTypes.number,

    /**
     * Optionally cause the tour to advance to the next step upon clicking the targeted element.
     * Only buttons are supported.
     */
    nextOnTargetClick: PropTypes.bool,

    /**
     * Validate before advancing the tour after clicking a button. Expects a promise resolving to a boolean.
     */
    validateNextOnTargetClick: PropTypes.func,
    orientationPreferences: PropTypes.oneOf(['east', 'east-north', 'east-south', 'south', 'south-east', 'south-west', 'west', 'west-north', 'west-south', 'north', 'north-east', 'north-west']),

    /**
     * If specified, the tour will try to target and position with respect to an element that is outside
     * of its parent container. The tour is still bound to its container, so this should only be used
     * sparingly in situations where it cannot be avoided.
     */
    allowForeignTarget: PropTypes.bool
  })).isRequired,

  /** Optionally specify a custom close function for the entire tour. Passed the current step index as a param.
   */
  onClose: PropTypes.func,

  /**
   * Optionally specify the starting step. If conditionally rendering ({showTour && <Tour... />})
   * this can be used to resume from a particular step, even after unmounting.
   */
  initialStepIndex: PropTypes.number,

  /**
   * Optionally specify whether the tour should update upon changes to the target's size or position.
   */
  movingTarget: PropTypes.bool,

  /**
   * Optional identifier to differentiate between multiple tours on the same page.
   */
  identifier: PropTypes.string,

  /**
   * Optionally specify whether the mask should be disabled
   */
  disableMask: PropTypes.bool,

  /**
   * Optionally disable automatic scrolling
   */
  disableAutoScroll: PropTypes.bool,

  /**
   * Optionally disable smooth scrolling
   */
  disableSmoothScroll: PropTypes.bool,

  /**
   * Optionally disables closing the tour on mask click
   */
  disableCloseOnClick: PropTypes.bool,

  /**
   * Optionally provide a callback that handles receiving an update function. Can be used to listen
   * for events and recalculate the tour's position when those events fire. The callback will be
   * passed `update` as an argument.
   */
  setUpdateListener: PropTypes.func,

  /**
   * Optionally provide a callback intended to remove the listener set by `setUpdateListener`.
   * The callback will be passed `update` as an argument. Should only and always be used with `setUpdateListener`.
   */
  removeUpdateListener: PropTypes.func,

  /**
   * Optionally specify whether the tour is active or not. If specified, the tour will act as
   * a controlled component, and will defer to this prop when closing.
   */
  isOpen: PropTypes.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: PropTypes.bool,

  /**
   * Optionally allow the tooltip to be flipped over, exposing secondary content on the back side.
   */
  enableFlip: PropTypes.bool,

  /**
   * Secondary Title, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedTitle: PropTypes.string,

  /**
   * Secondary body content, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedDescription: PropTypes.string,

  /**
   * Accessibility label text for the "close" button
   */
  closeButtonAriaLabel: PropTypes.string,

  /**
   * Accessibility label text for the "flip" button
   */
  flipButtonAriaLabel: PropTypes.string,

  /**
   * Optional selector to explicitly define where the tour components should be rendered in the DOM.
   * This impacts scrolling/scoping, and should only be used if absolutely necessary.
   */
  rootSelector: PropTypes.string
};
